Module protocol

Module protocol 

Defines the Celery protocol.

The top part of the protocol is the Message struct, which builds on top of the protocol for a broker. This is why a broker’s Delivery type must implement TryCreateMessage.

Structs

Delivery
DeliveryInfo
Additional message delivery information. This is a mapping containing the exchange and routing key used to deliver this task. Availability of keys in this dict depends on the message broker used.
DeliveryProperties
Message
A Message is the core of the Celery protocol and is built on top of a Broker’s protocol. Every message corresponds to a task.
MessageBody
The body of a message. Contains the task itself as well as callback / errback signatures and work-flow primitives.
MessageBodyEmbed
Contains callback / errback signatures and work-flow primitives.
MessageBuilder
Create a message with a custom configuration.
MessageHeaders
Additional meta data pertaining to the Celery protocol.
MessageProperties
Message meta data pertaining to the broker.

Enums

BodyEncoding
MessageContentType
Serialization formats supported for message body.

Traits

TryCreateMessage
A trait for attempting to create a Message from self. This will be implemented by types that can act like message “factories”, like for instance the Signature type.
TryDeserializeMessage
A trait for attempting to deserialize a Message from self. This is required to be implemented on a broker’s Delivery type.