MessageHeaders

Struct MessageHeaders 

pub struct MessageHeaders {
Show 15 fields pub id: String, pub task: String, pub lang: Option<String>, pub root_id: Option<String>, pub parent_id: Option<String>, pub group: Option<String>, pub meth: Option<String>, pub shadow: Option<String>, pub eta: Option<DateTime<Utc>>, pub expires: Option<DateTime<Utc>>, pub retries: Option<u32>, pub timelimit: (Option<u32>, Option<u32>), pub argsrepr: Option<String>, pub kwargsrepr: Option<String>, pub origin: Option<String>,
}
Additional meta data pertaining to the Celery protocol.

Fields

id: String

A unique ID of the task.

task: String

The name of the task.

lang: Option<String>

The programming language associated with the task.

root_id: Option<String>

The first task in the work-flow.

parent_id: Option<String>

The ID of the task that called this task within a work-flow.

group: Option<String>

The unique ID of the task’s group, if this task is a member.

meth: Option<String>

Currently unused but could be used in the future to specify class+method pairs.

shadow: Option<String>

Modifies the task name that is used in logs.

eta: Option<DateTime<Utc>>

A future time after which the task should be executed.

expires: Option<DateTime<Utc>>

A future time after which the task should be discarded if it hasn’t executed yet.

retries: Option<u32>

The number of times the task has been retried without success.

timelimit: (Option<u32>, Option<u32>)

A tuple specifying the hard and soft time limits, respectively.

Note that as of writing this, the Python celery docs actually have a typo where it says these are reversed.

argsrepr: Option<String>

A string representation of the positional arguments of the task.

kwargsrepr: Option<String>

A string representation of the keyword arguments of the task.

origin: Option<String>

A string representing the nodename of the process that produced the task.