TryCreateMessage

Trait TryCreateMessage 

pub trait TryCreateMessage: Send + Sync {
    // Required method
    fn try_create_message(&self) -> Result<Message, ProtocolError>;
}
A trait for attempting to create a Message from self. This will be implemented by types that can act like message “factories”, like for instance the Signature type.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> TryCreateMessage for Signature<T>
where T: Task + Clone,